"use strict";

exports.__esModule = true;
exports.default = void 0;

var _path = _interopRequireDefault(require("path"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const validate = options => {
  const {
    root,
    alias,
    path
  } = options;

  if (typeof root !== "string") {
    throw new Error(`babel-plugin-codemod-aliased-imports expected an \`root\` option of type string. Received ${root} instead.`);
  }

  if (typeof alias !== "string") {
    throw new Error(`babel-plugin-codemod-aliased-imports expected an \`alias\` option of type string. Received ${alias} instead.`);
  }

  if (typeof path !== "string") {
    throw new Error(`babel-plugin-codemod-aliased-imports expected an \`path\` option of type string. Received ${path} instead.`);
  }
};

var _default = api => {
  return {
    name: "codemod-aliased-imports",
    visitor: {
      ImportDeclaration(node, state) {
        validate(state.opts);
        const {
          opts: {
            root,
            alias,
            path: relativeAliasedPath
          }
        } = state;
        const source = node.get("source");

        if (!node.aliased) {
          const importPath = source.node.value;

          const fileDirname = _path.default.dirname(state.filename);

          const absoluteImportPath = _path.default.resolve(fileDirname, importPath);

          const absoluteAliasedPath = _path.default.resolve(_path.default.resolve(process.cwd(), root), relativeAliasedPath);

          node.aliased = true;
          source.replaceWith(api.types.stringLiteral(absoluteImportPath.replace(absoluteAliasedPath, alias)));
        }
      }

    }
  };
};

exports.default = _default;